class TreesController < ApplicationController
  before_action :set_tree, only: %i[show edit update destroy]

  def index
    @data = Lasha.index_data(
      controller: self,
      collection: Tree.all.order(created_at: :desc),
      attributes: %i[title content toggler],
      pagy_items: 10,
      scope_filters: true
    )
  end

  def show; end

  def new
    @tree = Tree.new
  end

  def edit; end

  def create
    @tree = Tree.new(tree_params)

    if @tree.save
      redirect_to @tree, notice: "Tree was successfully created."
    else
      render :new
    end
  end

  def update
    if @tree.update(tree_params)
      redirect_to @tree, notice: "Tree was successfully updated."
    else
      render :edit
    end
  end

  def destroy
    @tree.destroy
    redirect_to trees_url, notice: "Tree was successfully destroyed."
  end

  private

    def set_tree
      @tree = Tree.find(params[:id])
    end

    def tree_params
      params.require(:tree).permit(:title, :content, :toggler)
    end
end
